quarter_round

Function quarter_round 

pub(crate) fn quarter_round(
    a: usize,
    b: usize,
    c: usize,
    d: usize,
    state: &mut [u32; 16],
)
The ChaCha20 quarter round function

We located this function in the root of the crate as we want it to be available for the soft backend and for xchacha.