pub struct ChaChaCore<R: Rounds, V: Variant> {
pub(crate) state: [u32; 16],
pub(crate) tokens: (InitToken, InitToken),
pub(crate) _pd: PhantomData<(R, V)>,
}Expand description
The ChaCha core function.
Fields
state: [u32; 16]Internal state of the core function
tokens: (InitToken, InitToken)CPU target feature tokens
_pd: PhantomData<(R, V)>Number of rounds to perform and the cipher variant
Implementations
Sourceimpl<R: Rounds, V: Variant> ChaChaCore<R, V>
impl<R: Rounds, V: Variant> ChaChaCore<R, V>
Sourcepub(crate) fn new_internal(key: &[u8; 32], iv: &[u8]) -> Self
pub(crate) fn new_internal(key: &[u8; 32], iv: &[u8]) -> Self
Constructs a ChaChaCore with the specified key and iv.
You must ensure that the iv is of the correct size when using this method directly.
Panics
If iv.len() is not equal to 4, 8, or 12.
Sourcepub fn get_block_pos(&self) -> V::Counter
pub fn get_block_pos(&self) -> V::Counter
Get the current block position.
Sourcepub fn set_block_pos(&mut self, pos: V::Counter)
pub fn set_block_pos(&mut self, pos: V::Counter)
Set the block position.